import { Arch, ArchType } from "builder-util";
import { Publish } from "electron-builder-http/out/publishOptions";
export declare type TargetConfigType = Array<string | TargetConfiguration> | string | TargetConfiguration | null;
export interface TargetConfiguration {
    /**
     * The target name. e.g. `snap`.
     */
    readonly target: string;
    /**
     * The arch or list of archs.
     */
    readonly arch?: Array<ArchType> | ArchType;
}
export declare class Platform {
    name: string;
    buildConfigurationKey: string;
    nodeName: string;
    static MAC: Platform;
    static LINUX: Platform;
    static WINDOWS: Platform;
    static OSX: Platform;
    constructor(name: string, buildConfigurationKey: string, nodeName: string);
    toString(): string;
    createTarget(type?: string | Array<string> | null, ...archs: Array<Arch>): Map<Platform, Map<Arch, Array<string>>>;
    static current(): Platform;
    static fromString(name: string): Platform;
}
export declare abstract class Target {
    readonly name: string;
    readonly isAsyncSupported: boolean;
    readonly abstract outDir: string;
    readonly abstract options: TargetSpecificOptions | null | undefined;
    constructor(name: string, isAsyncSupported?: boolean);
    abstract build(appOutDir: string, arch: Arch): Promise<any>;
    finishBuild(): Promise<any>;
}
export interface TargetSpecificOptions {
    /**
     The [artifact file name template](/configuration/configuration.md#artifact-file-name-template).
     */
    readonly artifactName?: string | null;
    /**
     * The [publish configuration](/publishing-artifacts.md#publish-options). Order is important — first item will be used as a default auto-update server.
     *
     * If `GH_TOKEN` is set — defaults to `[{provider: "github"}]`.
     *
     * If `BT_TOKEN` is set and `GH_TOKEN` is not set — defaults to `[{provider: "bintray"}]`.
     */
    publish?: Publish;
}
export declare const DEFAULT_TARGET = "default";
export declare const DIR_TARGET = "dir";
export declare type CompressionLevel = "store" | "normal" | "maximum";
export interface BeforeBuildContext {
    readonly appDir: string;
    readonly electronVersion: string;
    readonly platform: Platform;
    readonly arch: string;
}
export interface SourceRepositoryInfo {
    type?: string;
    domain?: string;
    user: string;
    project: string;
}
